:orphan:

======================================
Salt Release Notes - Codename Nitrogen
======================================

Grains Changes
==============

- The ``os_release`` grain has been changed from a string to an integer.
  State files, especially those using a templating language like Jinja
  may need to be adjusted to account for this change.
